==> htmlunit-2.26-sources.jar: com/gargoylesoftware/htmlunit/javascript/host/svg/SVGForeignObjectElement.java <==
/*
 * Copyright (c) 2002-2017 Gargoyle Software Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.gargoylesoftware.htmlunit.javascript.host.svg;

import static com.gargoylesoftware.htmlunit.javascript.configuration.BrowserName.CHROME;
import static com.gargoylesoftware.htmlunit.javascript.configuration.BrowserName.EDGE;
import static com.gargoylesoftware.htmlunit.javascript.configuration.BrowserName.FF;

import com.gargoylesoftware.htmlunit.javascript.configuration.JsxClass;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstructor;
import com.gargoylesoftware.htmlunit.javascript.configuration.WebBrowser;
import com.gargoylesoftware.htmlunit.svg.SvgForeignObject;

/**
 * A JavaScript object for {@code SVGForeignObjectElement}.
 *
 * @author Ahmed Ashour
 * @author Frank Danek
 */
@JsxClass(domClass = SvgForeignObject.class, browsers = {@WebBrowser(FF), @WebBrowser(CHROME), @WebBrowser(EDGE)})
public class SVGForeignObjectElement extends SVGGraphicsElement {

    /**
     * Creates an instance.
     */
    @JsxConstructor
    public SVGForeignObjectElement() {
    }
}

==> htmlunit-2.28-sources.jar: com/gargoylesoftware/htmlunit/javascript/host/svg/SVGForeignObjectElement.java <==
/*
 * Copyright (c) 2002-2017 Gargoyle Software Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.gargoylesoftware.htmlunit.javascript.host.svg;

import static com.gargoylesoftware.htmlunit.javascript.configuration.SupportedBrowser.CHROME;
import static com.gargoylesoftware.htmlunit.javascript.configuration.SupportedBrowser.EDGE;
import static com.gargoylesoftware.htmlunit.javascript.configuration.SupportedBrowser.FF;

import com.gargoylesoftware.htmlunit.javascript.configuration.JsxClass;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstructor;
import com.gargoylesoftware.htmlunit.svg.SvgForeignObject;

/**
 * A JavaScript object for {@code SVGForeignObjectElement}.
 *
 * @author Ahmed Ashour
 * @author Frank Danek
 */
@JsxClass(domClass = SvgForeignObject.class, value = {FF, CHROME, EDGE})
public class SVGForeignObjectElement extends SVGGraphicsElement {

    /**
     * Creates an instance.
     */
    @JsxConstructor
    public SVGForeignObjectElement() {
    }
}
